@@ -14,7 +14,7 @@ use File::Spec::Functions qw(abs2rel catfile rel2abs splitdir);
 use App::Followme::FIO;
 use App::Followme::Web;
 
-our $VERSION = "1.90";
+our $VERSION = "1.91";
 
 #----------------------------------------------------------------------
 # Read the default parameter values
@@ -68,11 +68,16 @@ sub fetch_content {
                        );
 
         while (my ($cname, $sname) = each %mapping) {
-            my @tokens = web_split_at_tags($section->{$sname});
+            $content{$cname} = $section->{$sname};
+        }
+
+        foreach my $cname (qw(title)) {
+            my @tokens = web_split_at_tags($content{$cname});
             $content{$cname} = web_only_text(@tokens);
         }
     }
 
+
     return %content;
 }
 
